# WMCore
WMCore is a meta project providing multiple software for the CMS Workload Management system, such as WMAgent, ReqMgr2, Global WorkQueue, WMStats and ReqMgr2 MicroServices.
It also provides core libraries to other Data Management and Workload Management (DMWM) CMS services, like CRABServer, DBS3, Tier0, Unified.


## Documentation
General information, as well as development and testing documentation, can be found in our [GitLab docs](https://cms-wmcore.docs.cern.ch/), as the WMCore [wiki](https://github.com/dmwm/WMCore/wiki) has been phased out since the year 2024.

## Contributing
For guidance on setting up a development/testing environment and how to contribute to WMCore, please refer to the [CONTRIBUTING](https://github.com/dmwm/WMCore/blob/master/CONTRIBUTING.rst) guidelines.

## Getting Support
For project support and discussions, please join us on the CMS O&C organization in [CERN Mattermost](https://mattermost.web.cern.ch/cms-o-and-c). The relevant Mattermost channels are either `WM Dev` or `WM Ops`.
